@@ -369,7 +369,8 @@ class Client(object):
         return resp.json()["data"]
 
     def get_kline_history(
-        self, begin, end=None, interval:str="1day", msg:bool=False, warning:bool=True,
+        self, tickers:str or list, begin:dt.datetime or str, end:dt.datetime or str=None, 
+        interval:str="1day", msg:bool=False, warning:bool=True,
     ) -> pd.DataFrame:
         """Query historic OHLC(V) data for a ticker or list of tickers 
 
@@ -525,13 +526,36 @@ class Client(object):
         df.set_index("time", inplace=True)
         return df
 
-    def get_all_pairs(self) -> pd.DataFrame:
-        """Query API for dataframe containing detailed list of all currencies
+    def symbols(self, pair:str or list=None) -> pd.DataFrame or pd.Series:
+        """Query API for dataframe containing detailed list of trading pairs
+
+        This is the primary trading pair detail endpoint for users. The returned values
+        outline, in details, the trading parameters neccesary to successfully
+        execute trades. Several other pair, currency, and market detail endpoints are available,
+        but these endpoints primarily contain duplicate information to this detail or 
+        offer information largely unrelated to trade execution.
+
+        Notes
+        -----
+        There are several other currency detail endpoints: 
+        * `.get_currencies()`
+        * `.get_currency_detail()
+        * `.all_tickers`
+        * `.get_marginable_details()`
         
+        Parameters
+        ----------
+        currency : str
+            (Optional) Specify a single pair or list of pairs to query.
+            If currency = None, return a dataframe of all trading pairs.
+
         Returns
         -------
-        DataFrame
-            Returns pandas DataFrame with with detailed list of all traded currencies
+        DataFrame or Series
+            Returns pandas DataFrame with with detailed list of all traded pairs. 
+            If a list of pairs is provided in the `currency` parameter, return a
+            DataFrame containing only the specified pairs. If a single pair is 
+            provided, return a pandas Series with the pair trade details.
         """
         path = "symbols"
         url = self._request("get", path)
@@ -540,7 +564,11 @@ class Client(object):
             return print(resp.status_code)
         resp = resp.json()
         df = pd.DataFrame(resp["data"]).set_index("symbol")
-        df.iloc[:, 5:14] = df.iloc[:, 5:14].astype(float)
+        if pair:
+            try:
+                df = df.loc[pair, :]
+            except KeyError as e: 
+                raise KeyError("Keys not found in list frame", e)
         return df
 
     def get_margin_data(self, currency:str) -> pd.DataFrame:
